@@ -21,5 +21,5 @@ from eigeningenuity.historian import get_historian, list_historians, get_default
 
 from eigeningenuity.core import *
 
-__all__ = ["get_historian", "list_historians", "get_default_historian_name"]
-__version__ = pkg_resources.require("python-eigen-ingenuity")[0].version
+__all__ = ["get_historian", "list_historians", "get_default_historian_name","EigenServer"]
+# __version__ = pkg_resources.require("python-eigen-ingenuity")[0].version
