@@ -22,8 +22,8 @@ from eigeningenuity.util import _do_eigen_json_request, EigenException, RemoteSe
 
 _INSTANCE = None
 class EigenServer (object):
-    def __init__(self, name = None, disableSsl = False):
-        """Find the base URL for the Eigen Ingenuity server.
+    def __init__(self, name:str = None, disableSsl = False):
+        """Takes the base URL for the Eigen Ingenuity server.
         """
         if name is None:
             try:
